"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tls = require("tls");
var Socket = (function () {
    function Socket() {
    }
    Socket.tlsSocket = function (host, port, options, connectionTimeout) {
        if (connectionTimeout === void 0) { connectionTimeout = 3000; }
        return new Promise(function (resolve, reject) {
            var timeout = setTimeout(function () { return reject({ socket: socket, error: new Error('ECONN') }); }, connectionTimeout);
            var socket = tls.connect(port, host, options, function () {
                clearInterval(timeout);
                resolve(socket);
            });
        });
    };
    Socket.request = function (socket, id, method, params) {
        if (params === void 0) { params = []; }
        return new Promise(function (resolve, reject) {
            var body = JSON.stringify({
                jsonrpc: '2.0',
                id: id,
                method: method,
                params: params,
            });
            socket.on('data', function (chunk) {
                resolve(chunk);
                socket.removeAllListeners();
            });
            socket.on('error', function (e) {
                reject(new Error(e));
                socket.removeAllListeners();
            });
            socket.write(body + '\n');
        });
    };
    Socket.close = function (socket) {
        socket.end();
        socket.destroy();
    };
    Socket.getPeerCertificate = function (socket, full) {
        if (full === void 0) { full = true; }
        var cert = socket.getPeerCertificate(full);
        return cert;
    };
    Socket.derCertToPemCert = function (cert) {
        var chars = Buffer.from(cert).toString('base64').split('');
        var formattedCert = '-----BEGIN CERTIFICATE-----';
        for (var i = 0; i < chars.length; i++) {
            if (i % 64 === 0) {
                formattedCert += '\n';
            }
            formattedCert += chars[i];
        }
        formattedCert += '\n-----END CERTIFICATE-----';
        return formattedCert;
    };
    return Socket;
}());
exports.Socket = Socket;
